
[![Build Status](https://travis-ci.org/guyrux/PyTools-API-GitHub.svg?branch=main)](https://travis-ci.org/guyrux/PyTools-API-GitHub)
[![Updates](https://pyup.io/repos/github/guyrux/PyTools-API-GitHub/shield.svg)](https://pyup.io/repos/github/guyrux/PyTools-API-GitHub/)
[![Python 3](https://pyup.io/repos/github/guyrux/PyTools-API-GitHub/python-3-shield.svg)](https://pyup.io/repos/github/guyrux/PyTools-API-GitHub/)

Teste
